#
# spec file for package cross-x86_64-gcc5
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define pkgname cross-x86_64-gcc5
%define cross_arch x86_64
%define gcc_target_arch x86_64-suse-linux
%define gcc_icecream 1
#
# spec file for package gcc (Version 4.0.1)
#
# This file and all modifications and additions to the pristine
# package are under the same license as the package itself.
#
# Please submit bugfixes or comments via http://www.suse.de/feedback/
#

%define build_cp 1
%define build_ada 0
%define build_libjava 0
%define build_java 0

%define build_fortran 0
%define build_objc 0
%define build_objcp 0
%define build_go 0

%define binutils_target %{cross_arch}
%if %{cross_arch} == "armv7l" || %{cross_arch} == "armv7hl"
%define binutils_target arm
%endif
%if %{cross_arch} == "armv6l" || %{cross_arch} == "armv6hl"
%define binutils_target arm
%endif
%if %{cross_arch} == "armv5tel"
%define binutils_target arm
%endif
%if %{cross_arch} == "sparcv9"
%define binutils_target sparc
%endif
%define canonical_target %(echo %{binutils_target} | sed -e "s/i.86/i586/;s/ppc/powerpc/;s/sparc64.*/sparc64/;s/sparcv.*/sparc/;")
%if "%{binutils_target}" == "avr" || "%{binutils_target}" == "spu"
%define binutils_os %{canonical_target}
%else
%if "%{binutils_target}" == "arm"
%define binutils_os %{canonical_target}-suse-linux-gnueabi
%else
%define binutils_os %{canonical_target}-suse-linux
%endif
%endif

%if 0%{?gcc_icecream:1}
%define build_sysroot /
%else
# use same sysroot as in binutils.spec
%define sysroot %{_prefix}/%{binutils_os}/sys-root
%endif

Name:           %{pkgname}
BuildRequires:  bison
BuildRequires:  cross-%{binutils_target}-binutils
BuildRequires:  flex
BuildRequires:  gcc-c++
BuildRequires:  gettext-devel
BuildRequires:  mpc-devel
BuildRequires:  mpfr-devel
BuildRequires:  perl
%if %{suse_version} > 1220
BuildRequires:  makeinfo
%else
BuildRequires:  texinfo
%endif
BuildRequires:  zlib-devel
%ifarch %ix86 x86_64 ppc ppc64 s390 s390x ia64 %sparc hppa %arm
BuildRequires:  isl-devel
%endif
%ifarch ia64
BuildRequires:  libunwind-devel
%endif
%if 0%{!?gcc_icecream:1}
%if 0
%if 0%{!?gcc_libc_bootstrap:1}
BuildRequires:  cross-%cross_arch-newlib-devel
%endif
%else
BuildRequires:  cross-%cross_arch-glibc-devel
%endif
%endif
%if 0%{?gcc_icecream:1}
ExclusiveArch:  ppc64  ia64 s390x aarch64
%endif
%define _binary_payload w.ufdio
# Obsolete cross-ppc-gcc49 from cross-ppc64-gcc49 which has
# file conflicts with it and is no longer packaged
%if "%pkgname" == "cross-ppc64-gcc49"
Obsoletes:      cross-ppc-gcc49 <= 4.9.0+r209354
%endif

%define biarch_targets x86_64 s390x powerpc64 powerpc sparc sparc64

Url:            http://gcc.gnu.org/
Version:        5.5.0+r253576
Release:        1.1
%define gcc_version %(echo %version | sed 's/+.*//')
%define gcc_dir_version %(echo %gcc_version | cut -d '.' -f 1)
%define gcc_snapshot_revision %(echo %version | sed 's/[3-9]\.[0-9]\.[0-6]//' | sed 's/+/-/')
%define binsuffix -5
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Source:         gcc-%{version}.tar.bz2
Source1:        change_spec
Source2:        libffi-gcc5-rpmlintrc
Source3:        gcc5-rpmlintrc
Source4:        ecj.jar
Source5:        README.First-for.SuSE.packagers
Source6:        baselibs.conf
Source7:        libgcj-gcc5-rpmlintrc

#testpatch begin

Patch1:         gcc-dir-version.patch
Patch2:         gcc-add-defaultsspec.diff
Patch3:         Wunprototyped-calls.diff
Patch4:         libjava-no-multilib.diff
Patch5:         tls-no-direct.diff
Patch6:         gcc43-no-unwind-tables.diff
Patch7:         gcc48-libstdc++-api-reference.patch
Patch8:         gcc5-libsanitize-aarch64-va42.patch
Patch9:         gcc48-remove-mpfr-2.4.0-requirement.patch
Patch10:        gcc5-no-return-gcc43-workaround.patch
Patch11:        gcc5-aarch64-libffi.patch
Patch13:        gcc5-libsanitizer-ppc64le-signal.patch
# A set of patches from the RH srpm
Patch50:        gcc41-java-slow_pthread_self.patch
Patch51:        gcc41-ppc32-retaddr.patch
# Some patches taken from Debian
Patch60:        gcc44-textdomain.patch
Patch61:        gcc44-rename-info-files.patch
# Some libgo patches
Patch70:        gcc5-libgo-fix-certificates-lookup.patch
# https://github.com/libffi/libffi/pull/282
Patch100:       gcc5-libffi-pax.patch
Patch101:       gcc5-libffi-race-condition.patch

#testpatch end

Summary:        The GNU C Compiler and Support Files
License:        GPL-3.0+
Group:          Development/Languages/C and C++

%description
Core package for the GNU Compiler Collection, including the C language
frontend.

Language frontends other than C are split to different sub-packages,
namely gcc-ada, gcc-c++, gcc-fortran, gcc-java, gcc-objc and
gcc-obj-c++.




# Define the canonical target and host architecture
#   %gcc_target_arch  is supposed to be the full target triple
#   %cross_arch       is supposed to be the rpm target variant arch
#   %TARGET_ARCH      will be the canonicalized target CPU part
#   %HOST_ARCH        will be the canonicalized host CPU part
%if 0%{?gcc_target_arch:1}
%define TARGET_ARCH %(echo %{cross_arch} | sed -e "s/i.86/i586/;s/ppc/powerpc/;s/sparc64.*/sparc64/;s/sparcv.*/sparc/;")
%else
%define TARGET_ARCH %(echo %{_target_cpu} | sed -e "s/i.86/i586/;s/ppc/powerpc/;s/sparc64.*/sparc64/;s/sparcv.*/sparc/;")
%endif
%if 0%{?disable_32bit:1}
%define biarch 0
%else
%define biarch %(case " %{biarch_targets} " in (*" %{TARGET_ARCH} "*) echo 1;; (*) echo 0;; esac)
%endif

%define HOST_ARCH %(echo %{_host_cpu} | sed -e "s/i.86/i586/;s/ppc/powerpc/;s/sparc64.*/sparc64/;s/sparcv.*/sparc/;")
%ifarch ppc
%define GCCDIST powerpc64-suse-linux
%else
%ifarch %sparc
%define GCCDIST sparc64-suse-linux
%else
%ifarch %arm
%define GCCDIST %{HOST_ARCH}-suse-linux-gnueabi
%else
%define GCCDIST %{HOST_ARCH}-suse-linux
%endif
%endif
%endif

%define libsubdir %{_libdir}/gcc/%{GCCDIST}/%{gcc_dir_version}
%define gxxinclude %{_prefix}/include/c++/%{gcc_dir_version}

%prep
%setup -q -n gcc-%{version}

#test patching start

%patch1
%patch2
%patch3
%patch4
%patch5
%patch6
%patch7
%patch8
%if %{suse_version} < 1310
%patch9
%endif
%patch10
%if %{suse_version} <= 1320
%patch11
%endif
%patch13
%patch50
%patch51
%patch60
%patch61
%patch70
%patch100 -p1
%patch101 -p1

#test patching end

# We are configuring ppc as ppc64 but with switched multilibs.  Adjust
# the libstdc++ abi testsuite baseline files accordingly
%ifarch ppc
if [ -d libstdc++-v3/config/abi/post/powerpc64-linux-gnu ]; then
  mkdir -p libstdc++-v3/config/abi/post/powerpc64-linux-gnu/64
  mv libstdc++-v3/config/abi/post/powerpc64-linux-gnu/baseline_symbols.txt \
	libstdc++-v3/config/abi/post/powerpc64-linux-gnu/64/
  mv libstdc++-v3/config/abi/post/powerpc64-linux-gnu/32/baseline_symbols.txt \
	libstdc++-v3/config/abi/post/powerpc64-linux-gnu/
fi
%endif

%build
# Avoid rebuilding of generated files
contrib/gcc_update --touch
# Avoid fucking up testsuite results with Java and indirect dispatch
export SUSE_ASNEEDED=0
# Split version file into version used for directories (X) and
# version to report with --version (X.Y.Z).
# See also gcc-dir-version.patch.
mv gcc/BASE-VER gcc/FULL-VER
cat gcc/FULL-VER | cut -d '.' -f 1 > gcc/BASE-VER

# SLE11 does not allow empty rpms
%if %{suse_version} < 1310
echo "This is a dummy package to provide a dependency." > README
%endif

rm -rf obj-%{GCCDIST}
mkdir obj-%{GCCDIST}
cd obj-%{GCCDIST}
RPM_OPT_FLAGS="$RPM_OPT_FLAGS -U_FORTIFY_SOURCE"
RPM_OPT_FLAGS=`echo $RPM_OPT_FLAGS|sed -e 's/-fno-rtti//g' -e 's/-fno-exceptions//g' -e 's/-Wmissing-format-attribute//g' -e 's/-fstack-protector[^ ]*//g' -e 's/-ffortify=.//g' -e 's/-fstack-clash-protection//g' -e 's/-Wall//g' -e 's/-m32//g' -e 's/-m64//g'`
%ifarch %ix86
# -mcpu is superceded by -mtune but -mtune is not supported by
# our bootstrap compiler.  -mcpu gives a warning that stops
# the build process, so remove it for now.  Also remove all other
# -march and -mtune flags.  They are superseeded by proper
# default compiler settings now.
RPM_OPT_FLAGS=`echo $RPM_OPT_FLAGS|sed -e 's/-mcpu=i.86//g' -e 's/-march=i.86//g' -e 's/-mtune=i.86//g'`
%endif
%ifarch s390 s390x
RPM_OPT_FLAGS=`echo $RPM_OPT_FLAGS|sed -e 's/-fsigned-char//g'`
RPM_OPT_FLAGS=`echo $RPM_OPT_FLAGS|sed -e 's/-O1/-O2/g'`
%endif
%if 0%{?gcc_target_arch:1}
# Kill all -march/tune/cpu because that screws building the target libs
RPM_OPT_FLAGS=`echo $RPM_OPT_FLAGS|sed -e 's/-m\(arch\|tune\|cpu\)=[^ ]*//g'`
%endif
# Replace 2 spaces by one finally
RPM_OPT_FLAGS=`echo $RPM_OPT_FLAGS|sed -e 's/  / /g'`

languages=c
%if %{build_cp}
languages=$languages,c++
%endif
%if %{build_objc}
languages=$languages,objc
%endif
%if %{build_fortran}
languages=$languages,fortran
%endif
%if %{build_objcp}
languages=$languages,obj-c++
%endif
%if %{build_java}
languages=$languages,java
%endif
%if %{build_ada}
languages=$languages,ada
%endif
%if %{build_go}
languages=$languages,go
%endif

J=%{?jobs:%jobs}
if test -z "$J"; then
  J=$(getconf _NPROCESSORS_CONF)
  JL=$(($J * 2))
else
  test 1 -gt "$J" && J=1
  JL=$(($(getconf _NPROCESSORS_CONF)*2))
fi
if test "$J" == "0"; then
  J=1
fi
if test "$JL" == "0"; then
  JL=1
fi
PARALLEL="-j$J -l$JL"

# we don't want some miscompiles in the testsuite, or some fault in
# the compiler to kill the machine.  Hence we limit the amount of memory
# by the physical RAM plus half of swap
#MEM=$(free -m | awk '/^Mem:/ {print $2}')
#SWAP=$(free -m | awk '/^Swap:/ {print $2}')
#ulimit -v $(((MEM + SWAP/2)*1024))

# In general we want to ship release checking enabled compilers
# which is the default for released compilers
#ENABLE_CHECKING="--enable-checking=yes"
ENABLE_CHECKING="--enable-checking=release"
#ENABLE_CHECKING=""

# Work around tail/head -1 changes
export _POSIX2_VERSION=199209

%if %{build_ada}
# Using the host gnatmake like
#   CC="gcc%{hostsuffix}" GNATBIND="gnatbind%{hostsuffix}"
#   GNATMAKE="gnatmake%{hostsuffix}"
# doesn't work due to PR33857, so an un-suffixed gnatmake has to be
# available
mkdir -p host-tools/bin
cp -a /usr/bin/gnatmake%{hostsuffix} host-tools/bin/gnatmake
cp -a /usr/bin/gnatlink%{hostsuffix} host-tools/bin/gnatlink
cp -a /usr/bin/gnatbind%{hostsuffix} host-tools/bin/gnatbind
cp -a /usr/bin/gcc%{hostsuffix} host-tools/bin/gcc
ln -sf /usr/%{_lib} host-tools/%{_lib}
export PATH="`pwd`/host-tools/bin:$PATH"
%endif
#%if 0%{?gcc_target_arch:1}
#%else
#	--enable-threads=posix \
#%endif
#	--enable-shared \
%if "%{TARGET_ARCH}" == "armv7hl"
# temporary workaround for a miscompilation of hash functions in java code
GCJ_EXTRA_FLAGS="-marm"
%endif
CFLAGS="$RPM_OPT_FLAGS" CXXFLAGS="$RPM_OPT_FLAGS" XCFLAGS="$RPM_OPT_FLAGS" \
TCFLAGS="$RPM_OPT_FLAGS" GCJFLAGS="$RPM_OPT_FLAGS $GCJ_EXTRA_FLAGS" \
../configure \
	--prefix=%{_prefix} \
	--infodir=%{_infodir} \
	--mandir=%{_mandir} \
	--libdir=%{_libdir} \
	--libexecdir=%{_libdir} \
	--enable-languages=$languages \
	$ENABLE_CHECKING \
	--with-gxx-include-dir=%{_prefix}/include/c++/%{gcc_dir_version} \
	--enable-ssp \
	--disable-libssp \
%if 0%{!?build_libvtv:1}
	--disable-libvtv \
%endif
%ifarch %mpx_arch
	--enable-libmpx \
%endif
	--disable-plugin \
	--with-bugurl="http://bugs.opensuse.org/" \
	--with-pkgversion="SUSE Linux" \
%if !%{build_libjava}
        --disable-libgcj \
%else
	--with-java-home=%{_libdir}/jvm/java-1.5.0-gcj%{binsuffix}-1.5.0.0/jre \
	--with-ecj-jar=%{libsubdir}/ecj.jar \
        --disable-java-awt \
%if !%{biarch_libjava}
        --disable-libjava-multilib \
%endif
%endif
	--with-slibdir=/%{_lib} \
	--with-system-zlib \
	--enable-__cxa_atexit \
	--enable-libstdcxx-allocator=new \
	--disable-libstdcxx-pch \
%if 0%{suse_version} <= 1320
	--with-default-libstdcxx-abi=gcc4-compatible \
%endif
	--enable-version-specific-runtime-libs \
%if 0%{suse_version} > 1100
	--enable-linker-build-id \
%endif
	--enable-linux-futex \
	--program-suffix=%{binsuffix} \
%if 0%{?disable_32bit:1}
	--disable-multilib \
%endif
%if 0%{!?gcc_target_arch:1}
%ifarch ia64
	--with-system-libunwind \
%else
	--without-system-libunwind \
%endif
%endif
%if 0%{?gcc_target_arch:1}
	--program-prefix=%{gcc_target_arch}- \
	--target=%{gcc_target_arch} \
	--disable-nls \
%if 0%{?sysroot:1}
	--with-sysroot=%sysroot \
%else
	--with-sysroot=%{_prefix}/%{gcc_target_arch} \
%endif
%if 0%{?build_sysroot:1}
	--with-build-sysroot=%{build_sysroot} \
%else
%if 0%{?sysroot:1}
	--with-build-sysroot=%{sysroot} \
%else
	--with-build-sysroot=%{_prefix}/%{gcc_target_arch} \
%endif
%endif
%if 0%{?binutils_os:1}
	--with-build-time-tools=/usr/%{binutils_os}/bin \
%endif
%if "%{TARGET_ARCH}" == "spu"
	--with-gxx-include-dir=%sysroot/include/c++/%{gcc_dir_version} \
	--with-newlib \
%endif
%endif
%if "%{TARGET_ARCH}" == "armv5tel"
	--with-arch=armv5te \
	--with-float=soft \
	--with-mode=arm \
	--with-abi=aapcs-linux \
	--disable-sjlj-exceptions \
%endif
%if "%{TARGET_ARCH}" == "armv6hl"
        --with-arch=armv6zk \
        --with-tune=arm1176jzf-s \
        --with-float=hard \
        --with-abi=aapcs-linux \
        --with-fpu=vfp \
        --disable-sjlj-exceptions \
%endif
%if "%{TARGET_ARCH}" == "armv7hl"
	--with-arch=armv7-a \
	--with-tune=cortex-a15 \
	--with-float=hard \
	--with-abi=aapcs-linux \
	--with-fpu=vfpv3-d16 \
	--disable-sjlj-exceptions \
%endif
%if "%{TARGET_ARCH}" == "powerpc" || "%{TARGET_ARCH}" == "powerpc64" || "%{TARGET_ARCH}" == "powerpc64le"
%if "%{TARGET_ARCH}" == "powerpc"
        --with-cpu=default32 \
%endif
%if "%{TARGET_ARCH}" == "powerpc64le"
%if %{suse_version} >= 1315 && %{suse_version} != 1320
	--with-cpu=power8 \
	--with-tune=power8 \
%else
	--with-cpu=power7 \
	--with-tune=power7 \
%endif
%else
	--with-cpu-64=power4 \
%endif
	--enable-secureplt \
	--with-long-double-128 \
%if "%{TARGET_ARCH}" == "powerpc64le"
	--enable-targets=powerpcle-linux \
	--disable-multilib \
%endif
%endif
%if "%{TARGET_ARCH}" == "sparc64"
	--with-cpu=ultrasparc \
	--with-long-double-128 \
%endif
%if "%{TARGET_ARCH}" == "sparc"
	--with-cpu=v8 \
	--with-long-double-128 \
%endif
%if "%{TARGET_ARCH}" == "i586"
	--with-arch-32=i586 \
	--with-tune=generic \
%endif
%if "%{TARGET_ARCH}" == "x86_64"
	--enable-multilib \
	--with-arch-32=x86-64 \
	--with-tune=generic \
%endif
%if "%{TARGET_ARCH}" == "s390"
%if %{suse_version} >= 1310
        --with-tune=zEC12 --with-arch=z196 \
%else
	--with-tune=z9-109 --with-arch=z900 \
%endif
	--with-long-double-128 \
	--enable-decimal-float \
%endif
%if "%{TARGET_ARCH}" == "s390x"
%if %{suse_version} >= 1310
        --with-tune=zEC12 --with-arch=z196 \
%else
	--with-tune=z9-109 --with-arch=z900 \
%endif
	--with-long-double-128 \
	--enable-decimal-float \
%endif
%if "%{TARGET_ARCH}" == "m68k"
	--disable-multilib \
%endif
	--build=%{GCCDIST} \
	--host=%{GCCDIST}

%if 0%{!?gcc_icecream:1} && 0%{!?gcc_libc_bootstrap:1}
make %{?jobs:-j%jobs}
%else
make %{?jobs:-j%jobs} all-host
%endif

%if 0%{?gcc_icecream:1}
%package -n cross-%cross_arch-gcc5-icecream-backend
Summary:        Icecream backend for the GNU C Compiler
Group:          Development/Languages/C and C++

%description -n cross-%cross_arch-gcc5-icecream-backend
This package contains the icecream environment for the GNU C Compiler
%endif

%define targetlibsubdir %{_libdir}/gcc/%{gcc_target_arch}/%{gcc_dir_version}

%install
cd obj-%{GCCDIST}

# install and fixup host parts
make DESTDIR=$RPM_BUILD_ROOT install-host
%if 0%{?gcc_icecream:1}
# with the gcc_icecream setup fixincludes are for the build includes which
# is wrong - get rid of them
rm -rf $RPM_BUILD_ROOT/%{targetlibsubdir}/include-fixed
%endif
rm -f $RPM_BUILD_ROOT/%{targetlibsubdir}/liblto_plugin.la
# common fixup
rm -f $RPM_BUILD_ROOT%{_libdir}/libiberty.a

# install and fixup target parts
# debugedit is not prepared for this and crashes
%if 0%{?gcc_icecream:1}
# so expect the sysroot to be populated from natively built binaries
%else
%if 0%{!?gcc_libc_bootstrap:1}
export NO_BRP_STRIP_DEBUG=true
export NO_DEBUGINFO_STRIP_DEBUG=true
%define __debug_install_post %{nil}
: >debugfiles.list
: >debugsources.list
make DESTDIR=$RPM_BUILD_ROOT/%{sysroot} install-target
%endif
%endif

# remove docs
rm -rf $RPM_BUILD_ROOT%{_mandir}
rm -rf $RPM_BUILD_ROOT%{_infodir}

%if 0%{?gcc_icecream:1}
# Build an icecream environment
# The assembler comes from the cross-binutils, and hence is _not_
# named funnily, not even on ppc, so there we need the original target
install -s -D %{_prefix}/bin/%{binutils_os}-as \
	$RPM_BUILD_ROOT/env/usr/bin/as
install -s $RPM_BUILD_ROOT/%{_prefix}/bin/%{gcc_target_arch}-g++%{binsuffix} \
	$RPM_BUILD_ROOT/env/usr/bin/g++
install -s $RPM_BUILD_ROOT/%{_prefix}/bin/%{gcc_target_arch}-gcc%{binsuffix} \
	$RPM_BUILD_ROOT/env/usr/bin/gcc

for back in cc1 cc1plus; do 
	install -s -D $RPM_BUILD_ROOT/%{targetlibsubdir}/$back \
		$RPM_BUILD_ROOT/env%{targetlibsubdir}/$back
done
if test -f $RPM_BUILD_ROOT/%{targetlibsubdir}/liblto_plugin.so; then
  install -s -D $RPM_BUILD_ROOT/%{targetlibsubdir}/liblto_plugin.so \
		$RPM_BUILD_ROOT/env%{targetlibsubdir}/liblto_plugin.so
fi

# Make sure to also pull in all shared library requirements for the
# binaries we put into the environment which is operated by chrooting
# into it and execing the compiler
libs=`for bin in $RPM_BUILD_ROOT/env/usr/bin/* $RPM_BUILD_ROOT/env%{targetlibsubdir}/*; do \
  ldd $bin | sed -n '\,^[^/]*\(/[^ ]*\).*,{ s//\1/; p; }'  ;\
done | sort -u `
for lib in $libs; do
  # Check wether the same library also exists in the parent directory,
  # and prefer that on the assumption that it is a more generic one.
  baselib=`echo "$lib" | sed 's,/[^/]*\(/[^/]*\)$,\1,'`
  test -f "$baselib" && lib=$baselib
  install -s -D $lib $RPM_BUILD_ROOT/env$lib
done

cd $RPM_BUILD_ROOT/env
tar cvzf ../%{name}_%{_arch}.tar.gz *
cd ..
mkdir -p usr/share/icecream-envs
mv %{name}_%{_arch}.tar.gz usr/share/icecream-envs
rpm -q --changelog glibc >  usr/share/icecream-envs/%{name}_%{_arch}.glibc
rpm -q --changelog binutils >  usr/share/icecream-envs/%{name}_%{_arch}.binutils
rm -r env
%endif

%files
%defattr(-,root,root)
%{_prefix}/bin/%{gcc_target_arch}-*
%dir %{targetlibsubdir}
%dir %{_libdir}/gcc/%{gcc_target_arch}
%{targetlibsubdir}

%if 0%{!?gcc_icecream:1} && 0%{!?gcc_libc_bootstrap:1}
%{sysroot}
%endif

%if 0%{?gcc_icecream:1}
%files -n cross-%cross_arch-gcc5-icecream-backend
%defattr(-,root,root)
/usr/share/icecream-envs
%endif

%changelog
* Wed Oct 11 2017 rguenther@suse.com
- Update to GCC 5.5 which is the last release from the gcc-5-branch.
  * Includes similar fix to gcc41-ppc32-retaddr.patch, disable the
    patch but keep the testcase.
- Filter -fstack-clash-protection, BuildIgnore gcc-PIE, rename
  tarball to avoid %%version mangling.
* Wed Jun  7 2017 rguenther@suse.com
- Bump libffi version in libffi.pc to 3.99999.
* Fri Mar 31 2017 rguenther@suse.com
- Update to gcc-5-branch head (r246602).
- Drop now upstream gcc5-bnc986093.patch.
- Fix ExclusiveArch for aarch64 crosses.
- Package gcov-dump, refresh gcc44-rename-info-files.patch.
* Mon Feb 27 2017 rguenther@suse.com
- Add gcc5-libsanitizer-ppc64le-signal.patch to fix build with glibc 2.25.
* Thu Oct 20 2016 rguenther@suse.com
- Add gcc5-bnc986093.patch to fix wrong-code issue with jump threading
  across backedges.  [bnc#986093]
* Wed Sep 14 2016 rguenther@suse.com
- Update to gcc-5-branch head (r240125).
- Refresh gcc-dir-version.patch
* Fri Sep  9 2016 stbuehler@web.de
- fix 2 issues with libffi and mmap protection
  - fix race condition
  - check for PaX MPROTECT
  - make PaX EMUTRAMP experimental, disabling it
  - adds gcc5-libffi-pax.patch and gcc5-libffi-race-condition.patch
* Fri Jun  3 2016 rguenther@suse.com
- Update to GCC 5.4 release.
- Enable profiledbootstrap for x86_64, ppc64le, s390x and aarch64.
* Wed Apr 13 2016 rguenther@suse.com
- Enable Ada for ppc64le and aarch64.
* Tue Apr 12 2016 rguenther@suse.com
- Update to gcc-5-branch head (r234891).
  * Adds fix for PPC isinf simplification interaction with GNUlibs
    LDBL_MAX value.  [bnc#969323]
* Tue Mar 15 2016 rguenther@suse.com
- Honor %%disable_32bit forcing multilib disable.
* Mon Mar  7 2016 rguenther@suse.com
- Add gcc5-aarch64-libffi.patch to revert accidential libffi ABI
  breakage on AARCH64.  [bnc#968771]
* Tue Mar  1 2016 rguenther@suse.com
- Update to gcc-5-branch head (r233831).
  * Includes fixes for [bnc#966220], [bnc#962765] and [bnc#964468].
* Mon Dec  7 2015 rguenther@suse.com
- Update to GCC 5.3.1 (r231346).
  * Includes GCC 5.3 release with many bugfixes.
- Drop cloog-isl build dependency from cross packages.
* Fri Nov 20 2015 rguenther@suse.com
- Update to gcc-5-branch head (r230656).
  * Includes fix for HTM builtins on powerpc.  [bnc#955382]
  * Includes fix for build with ISL 0.15.
* Mon Nov  9 2015 rguenther@suse.com
- For x86_64 default 32bit code generation to -march=x86-64 rather
  than -march=i586.
- Fix libgo certificate lookup, adds gcc5-libgo-fix-certificates-lookup.patch.
  [bsc#953831]
- Build s390[x] with --with-tune=z9-109 --with-arch=z900 on SLE11
  again.  [bnc#954002]
* Thu Oct  8 2015 rguenther@suse.com
- Update to gcc-5-branch head (r228589).
  * Includes fix for [bnc#939460].
  * Includes fix for C++11 std::random_device short reads, CVE-2015-5276.
    [bnc#945842]
  * Experimental File System TS library.
- For non-icecream cross-compilers %%sysroot is always defined,
  so any conditionalization can be dropped as cleanup.
* Fri Sep 18 2015 dvaleev@suse.com
- Optimize ppc64le for power8 on Tumbleweed
* Tue Jul 21 2015 meissner@suse.com
- filter out -fstack-protector-strong too
* Tue Jul 21 2015 rguenther@suse.com
- Update to gcc-5-branch head (r226025).
  * Includes GCC 5.2 release
  * Includes post-release fix for Wine.
* Tue Jul 14 2015 rguenther@suse.com
- Allow for %%{binutils_target} containing dashes by quoting in %%if.
- Postpone docs cleanup beyond target installation.
- Assure files in %%{_bindir} have the expected prefix.
* Mon Jul 13 2015 rguenther@suse.com
- Update to gcc-5-branch head (r225724).
  * Includes GCC 5.2 RC2
- Adjust .changes file generation for optional compiler build.
* Tue Jul  7 2015 rguenther@suse.com
- Update to gcc-5-branch head (r225500).
  * Includes GCC 5.2 RC1
- Pack s390[x] vecintrin.h file.
- Adjust optional compiler setup to also build Ada and Go and keep
  separate spec files for libffi and the testsuite.
* Tue Jun 30 2015 schwab@suse.de
- Add cross-m68k-gcc5
* Wed Jun 24 2015 matz@suse.com
- Remove include-fixed/linux/vt.h as well.
* Mon Jun 22 2015 rguenther@suse.com
- Update to gcc-5-branch head (r224716).
- Fix libffi include install.  [bnc#935510]
- Package new mwaitxintrin.h file.
* Tue Jun  9 2015 rguenther@suse.com
- Update to gcc-5-branch head (r224257).
* Mon Jun  8 2015 rguenther@suse.com
- Fix build against SLE11 SP4.
  * Where mpfr 2.4.0 is not available disable the few features
    requiring it to allow building with mpfr 2.3.2,
    gcc48-remove-mpfr-2.4.0-requirement.patch.
  * Disable building the MPX library.
  * Re-instantiate IA64 support.
  * Add gcc5-no-return-gcc43-workaround.patch to avoid bogus warnings
    from the GCC 4.3 host compiler.
* Mon May 18 2015 rguenther@suse.com
- Update to gcc-5-branch head (r223279).
  * Includes fix for [bnc#930496] and [bnc#930392].
- Enable 32bit code generation for ppc64le but do not build 32bit
  target libraries.  Fixes ppc64le kernel compile.
* Fri May  8 2015 rguenther@suse.com
- Update to gcc-5-branch head (r222900).
- Add proper dependences to -32bit/-64bit compiler variants.  Add
  gcc5-c++-32/64bit and gcc5-obj-c++-32/64bit (for their dependencies
  only).
- Rename libstdc++5-devel to libstdc++6-devel-gcc5 following shared
  library suffixing (but applying always).
- Likewise for libgcj devel and jar packages and for libffi.
- Renames libgcj and libffi spec files.
* Mon Apr 27 2015 rguenther@suse.com
- Update to gcc-5-branch head (r222451).
  * Includes GCC 5.1.0 release and first chunk of bugfixes and powerpc
    backports.
- Enable building libmpx for i586 and x86_64.
* Mon Apr 20 2015 rguenther@suse.com
- Update to gcc-5-branch head (r222226).
  * Includes GCC 5.1 RC2.
* Thu Apr 16 2015 rguenther@suse.com
- Update to gcc-5-branch head (r222139).
* Mon Apr 13 2015 rguenther@suse.com
- Update to gcc-5-branch head (r222032).
  * Matches GCC 5.1 RC1.
* Thu Apr  9 2015 rguenther@suse.com
- Update to SVN trunk head (r221942).
* Tue Apr  7 2015 afaerber@suse.de
- Prepare for non-icecream cross-compilers
  * Define sysroot to match cross-binutils config
  * Prepare for requiring cross-newlib for some targets
  * Use all-host target for libc bootstrap, too
  * Install target files, but suppress stripping them (breaks them)
  * Suppress -icecream-backend subpackage
  * Allow building on any architecture
* Tue Apr  7 2015 rguenther@suse.com
- Update to SVN trunk head (r221888).
- Enable cross compiler builds.
* Thu Apr  2 2015 schwab@suse.de
- libsanitizer-tsan-res-state.patch: remove obsolete patch.
- gcc5-libsanitize-aarch64-va42.patch: support aarch64 42-bit address
- space
* Tue Mar 24 2015 rguenther@suse.com
- Update to SVN trunk head (r221624).
- Require own ada version for suse_version > 1330, not explicitely
  gcc49-ada.
- Amend _constraints to request more physical memory for gcc5 and
  gcc5-testresults as well as 4 processors for gcc5.
* Thu Mar 19 2015 rguenther@suse.com
- Update to SVN trunk head (r221515).
* Wed Mar 18 2015 rguenther@suse.com
- Update to SVN trunk head (r221482).
  * Fixes miscompile of vim.
* Tue Mar 10 2015 rguenther@suse.com
- Update to SVN trunk head (r221322).
  * Contains fixes for PR65120 and should reduce the amount of
    false -Wlogical-not-parentheses warnings.
- Switch to release checking builds.
* Tue Mar  3 2015 rguenther@suse.com
- Update to SVN trunk head (r221139).
  * Includes gcc5-pr65040.patch which is now removed.
- Add libsanitizer-tsan-res-state.patch to fix build with new glibc.
- Enable asan and ubsan for ppc64le.
* Fri Feb 27 2015 rguenther@suse.com
- Add gcc5-pr65040.patch to remove -Wformat-signedness from -Wformat=2.
- Renumber patches.
* Wed Feb 25 2015 rguenther@suse.com
- Update to SVN trunk head (r220959).
* Fri Feb 20 2015 rguenther@suse.com
- Update to SVN trunk head (r220833).
* Tue Feb 17 2015 rguenther@suse.com
- Update to SVN trunk head (r220758).
* Fri Feb 13 2015 rguenther@suse.com
- Update to SVN trunk head (r220678).
* Wed Feb 11 2015 rguenther@suse.com
- Update to SVN trunk head (r220617).
* Tue Feb 10 2015 rguenther@suse.com
- Update to SVN trunk head (r220580).
- Pulls bugfixing from Fedora mass-rebuild.
* Wed Jan 28 2015 rguenther@suse.com
- Update to SVN trunk head (r220205).
- Strip GO binaries again.
* Fri Jan 23 2015 rguenther@suse.com
- Update to SVN trunk head (r220030).
- Package go and gofmt manpages.
* Thu Jan 22 2015 rguenther@suse.com
- Update to SVN trunk head (r219990).
- Make sure to not strip GO binaries as that makes them fail to run.
- Bump libgcj SO version.
* Tue Jan 20 2015 rguenther@suse.com
- Update to SVN trunk head (r219892).
- Do not remove fixed includes for non-icecream like built crosses.
- Use the C++98 libstdc++ ABI by default on openSUSE 13.2 and older.
* Thu Jan 15 2015 rguenther@suse.com
- Update to SVN trunk head (r219634).
- Bump libgo SO version.
* Tue Jan 13 2015 rguenther@suse.com
- Update to SVN trunk head (r219531).
- Update gcc-dir-version.patch with upstream libgcj.pc file name changes.
* Mon Dec 15 2014 rguenther@suse.com
- Update to SVN trunk head (r218749).
- Drop gcc5-pr61558.patch.
* Fri Dec 12 2014 rguenther@suse.com
- Update to SVN trunk head (r218668).
- Enable GRAPHITE everywhere.
- Add gcc5-pr61558.patch to help identifying that issue easier.
* Wed Dec 10 2014 rguenther@suse.com
- Update to SVN trunk head (r218580).
* Tue Dec  2 2014 rguenther@suse.com
- Update to SVN trunk head (r218267).
  * Obsoletes gcc5-libsanitizer-fix.diff and gcc5-fix-gnatvsn.patch
* Fri Nov 21 2014 rguenther@suse.com
- Add gcc5-libsanitizer-fix.diff to fix bug in libsanitizer that
  prevents build on aarch64.
* Tue Nov 18 2014 rguenther@suse.com
- Update to SVN trunk head (r217714).
  * should fix non-%%x86 build.
* Mon Nov 17 2014 rguenther@suse.com
- New package, inherits from gcc49
  * gcc-dir-version.patch, drop patchlevel from install directory names
  * gcc-add-defaultsspec.diff, add the ability to provide a specs file
  that is read by default
  * Wunprototyped-calls.diff, new warning to warn about calls to functions
  without seeing a real prototype earlier
  * libjava-no-multilib.diff, do not build multilibs for libjava even on
  multilib systems (we use baselibs for it)
  * tls-no-direct.diff, avoid direct %%fs references on x86 to not slow down
  Xen
  * gcc43-no-unwind-tables.diff, do not produce unwind tables for CRT files
  * gcc41-java-slow_pthread_self.patch, force us to assume pthread_self
  is fast
  * gcc41-ppc32-retaddr.patch, fix expansion of __builtin_return_addr for ppc
  * gcc44-textdomain.patch, make translation files version specific and
  adjust textdomain to find them
  * gcc44-rename-info-files.patch, fix cross-references in info files when
  renaming them to be version specific
  * gcc48-libstdc++-api-reference.patch, fix link in the installed libstdc++
  html documentation
- Adds the following patches
  * gcc5-fix-gnatvsn.patch, fix PR63931
- Drops IA64 support.
